==> tentackle-swing-rdc-2.0.4-sources.jar: org/tentackle/swing/rdc/GuiProviderFactory.java <==
/**
 * Tentackle - http://www.tentackle.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package org.tentackle.swing.rdc;

import org.tentackle.common.ServiceFactory;
import org.tentackle.pdo.PersistentDomainObject;


interface GuiProviderFactory$Singleton {
  static GuiProviderFactory INSTANCE = ServiceFactory.createService(GuiProviderFactory.class, DefaultGuiProviderFactory.class);
}


/**
 * A factory for {@link GuiProvider}s.
 *
 * @author harald
 */
public interface GuiProviderFactory {

  /**
   * The singleton.
   *
   * @return the singleton
   */
  static GuiProviderFactory getInstance() {
    return GuiProviderFactory$Singleton.INSTANCE;
  }

  /**
   * Creates a service object that provides methods related to the rdc gui.
   *
   * @param <T> the PDO's class
   * @param pdo the PDO
   * @return the service object
   */
  <T extends PersistentDomainObject<T>> GuiProvider<T> createGuiProvider(T pdo);

}

==> tentackle-swing-rdc-2.1.2-sources.jar: org/tentackle/swing/rdc/GuiProviderFactory.java <==
/**
 * Tentackle - http://www.tentackle.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package org.tentackle.swing.rdc;

import org.tentackle.common.ServiceFactory;
import org.tentackle.pdo.PersistentDomainObject;


interface GuiProviderFactory$Singleton {
  GuiProviderFactory INSTANCE = ServiceFactory.createService(GuiProviderFactory.class, DefaultGuiProviderFactory.class);
}


/**
 * A factory for {@link GuiProvider}s.
 *
 * @author harald
 */
public interface GuiProviderFactory {

  /**
   * The singleton.
   *
   * @return the singleton
   */
  static GuiProviderFactory getInstance() {
    return GuiProviderFactory$Singleton.INSTANCE;
  }

  /**
   * Creates a service object that provides methods related to the rdc gui.
   *
   * @param <T> the PDO's class
   * @param pdo the PDO
   * @return the service object
   */
  <T extends PersistentDomainObject<T>> GuiProvider<T> createGuiProvider(T pdo);

}
